caltib - Interactive Calendar

packages = ["./caltib-0.1.0-py3-none-any.whl"]

### Settings

Calculation Engine
Location
Language
Initializing Environment...

## Loading...

Gregorian
--
Weekday
--
Tibetan Year
--
Lunar Month
--
Tithi (Lunar Day)
--
Astrological Attributes (Pending)
Loading...
True Planetary Positions (Pending)
Sun: 331.2° Moon: 12.4° Mars: ...

## Loading...

Year:

## Losar / Tsagaan Sar Finder

From To
Powered by caltib — Designed by Gantumur